function olaqueus_pulsespeed

%Octopus laqueus

fdir = 'C:\Users\Martin How\OneDrive - University of Bristol\marvefiles5\manuscripts\2017_Ceph_apparent_motion\Frontiers_2ndSub\cuttledynamicdisp\Octopus_laqueus';
fname = 'Octopus_laqueus_02.mat';


%Load data
load(fullfile(fdir,fname));
wave = s.point(:,1:2); 
indw = wave(:,1)==0&wave(:,2)==0;
wave(indw,1)=nan; wave(indw,2)=nan;
eye  = s.point(:,9:10);
bg1  = s.point(:,5:6);
bg2  = s.point(:,7:8);

%Make single vector out of the two overlapping background vectors
ind = bg1(:,1)==0&bg1(:,2)==0&bg2(:,1)==0&bg2(:,2)==0;
if sum(ind)>0
	pf = find(all(ind==1));
	error('Above frames do not contain background data')
end
indout = [];
for ii = 1:2
	if ii==1, bg = bg1; end
	if ii==2, bg = bg2; end
	ind = bg(:,1)==0&bg(:,2)==0;
	inds = ind(1:end-1)==1&ind(2:end)==0;
	inde = ind(1:end-1)==0&ind(2:end)==1;
	if sum(bg(1,1:2))>0
		inds = [1;inds];
	else
		inds = [0;inds];
	end
	if sum(bg(end,1:2))>0
		inde = [inde;1];
	else
		inde = [inde;0];
	end
	inds = find((inds==1));
	inde = find((inde==1));
		inde(:,2)=ii;
	indout=[indout;[inds,inde]];
end

indout = sortrows(indout);

ovec = zeros(s.nframes,2);

%Plot figure
figure(1); clf;
hold on
for rr = 1:size(indout,1)
	switch indout(rr,3)
		case 1, bg = bg1; bgo = bg2;
		case 2, bg = bg2; bgo = bg1;
	end
	if rr==1
		ovec(indout(1,1):indout(1,2),:) = ...
			bg(indout(1,1):indout(1,2),:);
		%plot(bg(indout(rr,1):indout(rr,2),1),...
		%	bg(indout(rr,1):indout(rr,2),2),'-k');
	else
		%plot(bg(indout(rr,1):indout(rr,2),1),...
		%	bg(indout(rr,1):indout(rr,2),2),'-r');
		
		sknum = [indout(rr,1) indout(rr-1,2)];
		skvec = bg(sknum(1),:)-bgo(sknum(1),:);
		%plot([0 skvec(1)],[0 skvec(2)],'g')
		
		ovec(sknum(1):indout(rr,2),:) =...
			[bg(sknum(1):indout(rr,2),1)-skvec(1),...
			 bg(sknum(1):indout(rr,2),2)-skvec(2)];
		bg(sknum(1):end,:) =...
			[bg(sknum(1):end,1)-skvec(1),...
			 bg(sknum(1):end,2)-skvec(2)];
		bgo(sknum(1):end,:) =...
			[bgo(sknum(1):end,1)-skvec(1),...
			 bgo(sknum(1):end,2)-skvec(2)];
				   
		%plot(ovec(:,1),ovec(:,2),'b')
		%if rr==3, error; end
	
	end
	switch indout(rr,3)
		case 1, bg1=bg; bg2=bgo;
		case 2, bg2=bg; bg1=bgo;
	end
end


%Smooth background and eye coordinates
ovec = [smooth(ovec(:,1),5),smooth(ovec(:,2),5)];
eye = [smooth(eye(:,1),5),smooth(eye(:,2),5)];

[~,vel] = cart2pol(ovec(2:end,1)-ovec(1:end-1,1),...
	ovec(2:end,2)-ovec(1:end-1,2));
vel = [0;vel];
tl = [1:length(vel)]./s.framerate;

%Index waves
indw = ~isnan(wave(:,1));

figure(1);clf; set(gcf,'menubar','figure')
hold on;

area(tl,indw.*50)
plot(tl,vel);
hold off
xlim([25 52]); ylim([0 25]);

%Index start and end of all waves
indws = isnan(wave(1:end-1,1))&~isnan(wave(2:end,1));
indwe = ~isnan(wave(1:end-1,1))&isnan(wave(2:end,1));
disp(['Animal produced ' num2str(sum(indws)) ' pulses in ' num2str(length(wave)./s.framerate) ' s'])
indw = [find(indws==1),find(indwe==1)];

disp('Frequency (waves per second)')
sum(indws)/(length(wave)./s.framerate)


%vel = smooth(vel,3);
startspeed = vel(indw(:,1)-5);
endspeed = vel(indw(:,2)+5);

disp('Mean start and end speed')
[mean(startspeed) mean(endspeed)]
disp('Std start and end speed')
[std(startspeed) std(endspeed)]

[h,p,ci,stats] = ttest(startspeed-endspeed)

disp('Mean and std pulse length (s)')
[mean(indw(:,2)-indw(:,1))/s.framerate,std(indw(:,2)-indw(:,1))/s.framerate]

%figure(2); clf;set(gcf,'menubar','figure')
hold on
errorbar([50 52],[mean(startspeed) mean(endspeed)],...
	[std(startspeed) std(endspeed)],[std(startspeed) std(endspeed)],...
	'linestyle','none','marker','.','markersize',15)
hold off








